import { Request, Response } from "express";
import BoatType from "../db/models/BoatType";

//show all BoatTypes(in wiki the name and the seats are returned, but maybe we need the new added boatType attribute??)
const showAllBoatTypes = async (req: Request, res: Response) => {
  try {
    if (!(res.locals.user.role === "coordinator")) {
      return res
        .status(403)
        .json({ success: false, error: "MustBeCoordinator" });
    }
    const allBoatTypes = await BoatType.findAll();
    return res.status(200).send({ success: true, result: allBoatTypes });
  } catch (error) {
    console.error("server error: ", error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};

//createBoatTypeController
const createBoatTypeController = async (req: Request, res: Response) => {
  try {
    if (!(res.locals.user.role == "coordinator")) {
      return res
        .status(403)
        .json({ success: false, error: "MustBeCoordinator" });
    }

    const newBoatTypeInput = req.body;

    console.log("input von req.body: ", newBoatTypeInput);

    const newBoatType = await BoatType.create(newBoatTypeInput);

    const { id, name, seats } = newBoatType;

    if (newBoatType) {
      return res
        .status(201)
        .json({ success: true, result: { id, name, seats } });
    }
  } catch (error) {
    console.error(error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};

const boatTypeControllers = {
  showAllBoatTypes,
  createBoatTypeController,
};

export default boatTypeControllers;
