import Worker from "../db/models/Worker";
import { Request, Response } from "express";
import bcrypt from "bcrypt";

//show current user GET
const showCurrentUserController = async (req: Request, res: Response) => {
  try {
    const currentUser = res.locals.user; //payload
    const currentUserData = await Worker.findOne({
      where: {
        email: currentUser.email,
      },
    });

    res.status(200).json({ success: true, result: currentUserData });
  } catch (error) {
    console.log("server error: ", error.message);
    res.status(500).json({ success: false, error: "serverError!" });
  }
};

//update current user PUT
const updateCurrentUser = async (req: Request, res: Response) => {
  try {
    //check role
    if (!(res.locals.user.role === "coordinator")) {
      return res
        .status(403)
        .json({ success: false, error: "MustBeCoordinator" });
    }

    //take what ever in req.body is, and pass it to update()
    const input = req.body; //Data are saved in the DB in camelCase

    if (input.password !== undefined) {
      input.password = await bcrypt.hash(input.password, 10);
    }

    const currentUser = res.locals.user;
    const currentUserEmail = currentUser.email; //updating data of current user: payload in token has the unique email + role

    //update coordinator data after finding wanted user through found email
    const workerDataAfterUpdate = await Worker.update(input, {
      where: {
        email: currentUserEmail,
      },
      returning: true,
    });

    const updatedWorker = workerDataAfterUpdate[1][0];
    delete updatedWorker.password;

    return res.status(200).json({ success: true, result: updatedWorker });
  } catch (error) {
    console.error("server error: ", error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};

const userControllers = {
  showCurrentUserController,
  updateCurrentUser,
};

export default userControllers;
